Calculates lag based on fitting baranyi model to data
calc_baranyi_fit_lag(
data,
n0,
init_lag = NULL,
init_gr_rate = NULL,
algorithm = "auto",
max_iter = 100
)growth curve data with additional columns ('lag', and predicted biomass 'predicted')
a data frame with two required columns names: "time" and "biomass",and one optional column: "curve_id" This is data from may come from multiple growth curves
a data frame describing initial biomass for each of the curves, i.e. it has two obligatory columns: "curve_id", "N0"
initial value for the lag parameter, defaults to NULL in which case it will be approximated based on the data
initial value for the growth rate, defaults to NULL in which case it will be approximated based on the data
eg. "auto", "Levenberg-Marquardt", "port", defaults to "auto"
Maximum number of iterations, defaults to 100