Runs nlsLM/nls algorithms with three different parameter setups to fit the best Logistic model parameters to our data and chooses the best model
calc_lag_fit_to_baranyi_with_lag(
gr_curve,
LOG10N0 = NULL,
init_lag = NULL,
init_mumax = NULL,
init_LOG10Nmax = NULL,
algorithm = "auto",
max_iter = 100,
lower_bound = c(0, 0, 0, 0)
)lag and the nls fitting object with parameters fitted to logistic model
data from one specific growth curve with these two columns: time and biomass
the decimal logarithm of initial biomass
initial value for the lag parameter
initial value for the mumax parameter
initial value for the LOG10Nmax parameter
defaults to "auto" which chooses between bounded and unbounded Levenberg-Marquardt method and the bounded port method
max. number of itertaions; defaults to 100
lower.bound for the bounded nls optimisation; defaults to 0