Runs nlsLM/nls algorithm of the user's choice to fit the Logistic model parameters to our data
calc_lag_fit_to_logistic_with_lag(
gr_curve,
n0,
init_gr_rate = init_gr_rate,
init_K = init_K,
init_lag = init_lag,
algorithm = "auto",
max_iter = 100,
lower_bound = c(0, 0, 0)
)lag and the nls fitting object with parameters fitted to logistic model
data from one specific growth curve with these two columns: time and biomass
the initial biomass
initial value for the growth rate
initial value for the saturation parameter K
initial value for the lag parameter
defaults to "auto" which chooses between bounded and unbounded Levenberg-Marquardt method and the bounded port method
max. number of iterations; defaults to 100
lower bound for the bounded nls optimization; defaults to 0