Runs nlsLM/nls algorithms with three different parameter setups to fit the best Baranyi parameters to our data and chooses the best model
choose_lag_fit_algorithm_baranyi(
gr_curve,
LOG10N0,
init_lag,
init_mumax,
init_LOG10Nmax,
max_iter,
lower_bound
)the best nls fitting object with parameters fitted to Baranyi model (lowest Res.Sum Sq provided that all coefficients are nonnegative)
data from one specific growth curve with the following columns: LOG10N, t
init value for the LOG10N0 parameter
initial value for the lag
initial value for the mumax parameter
initial value for the LOG10Nmax parameter
max. number of iterations
lower bound for the bounded nls optimization;