Runs nlsLM/nls algorithms with three different parameter setups to fit the best Logistic model parameters to our data and chooses the best model
choose_lag_fit_algorithm_logistic(
gr_curve,
n0,
init_gr_rate = init_gr_rate,
init_K = init_K,
init_lag = init_lag,
max_iter = 100,
lower_bound = c(0, 0, 0)
)the best nls fitting object with parameters fitted to logistic model (lowest Res.Sum Sq provided that all coefficients are nonnegative)
data from one specific growth curve with the following columns: LOG10N, t
the initial biomass
initial value for the growth rate
initial value for the saturation parameter K
initial value for the lag parameter
max. number of iterations; defaults to 100
lower bound for the bounded nls optimization; defaults to 0