Fits the lag to one growth curve based on the basic tangent method
fit_exp_lag_to_curve(data, n0, tangent_method = "to.point", curve_points = 3)line_slope: slope of the tangent line, line_intercept: intercept of the tangent line, lag: lag, tangent_points: i..e a data frame of all points selected for fitting the line
a data frame with two required columns names: "time" and "biomass", This is data from one growth curve only, one (mean) observation per time
the initial biomass (a tangent line crossing N0 line will determine the lag)
"local.regression" (if the tangent is fitted to a number of points around the maximal growth rate) or "to.point" (if the tangent is fitted only to the point where the growth rate is maximal); defaults to "to.point"
if tangent_method = "local.regression" then curve_points is the number of points the line is fitted to; defaults to 3 i.e. the point with the maximal uptake rate one point before and one point after