Finds reasonable approximation for baranyi growth curve parameters (init_mumax, lag) based on the growth curve and some initial values These approximations will be used as the initial values for the proper optimization algorithm run later.
get_init_pars_baranyi(
data_this_curve,
this_n0,
init_lag,
init_gr_rate,
min_b = 0.2,
min_a = 0.8
)list of parameters: init_mumax, init_lag
data from one specific growth curve with these two columns: time and biomass
the initial biomass
initial value for the lag parameter
initial value for the growth rate
defaults to 0.2; mina and minb define where to look for exponential phase: it will be where the biomass is between min + (max-min)*(mina TO minb)
defaults to 0.8