Fits the lag to multiple growth curves based on the biomass increase method
lag_biomass_incr(data, threshold, n0)growth curve data (as input) together with additional columns: N0, increase.from.N0, lag
a data frame with two required columns names: "time" and "biomass",and one optional column: "curve_id" This is data from may come from multiple growth curves
A value of the biomass increase that we can surely associate with the end of the lag phase rather than random variation during the lag
the initial biomass (lag will be defined as the time point where the difference between biomass and N0 reaches a predefined threshold)