Learn R Programming

miLAG (version 1.0.5)

make_grwoth_curve_df: make_grwoth_curve_df

Description

Create a growth curve data frame that can be later passed to the lag clculation functions

Usage

make_grwoth_curve_df(time, biomass, curve_id = NULL)

Value

a data frame representing growth curve data

Arguments

time

numeric vector of times when biomass was measured (chronologically ordered as in growth curve)

biomass

numeric vector of measured biomass values (chronologically ordered as in growth curve)

curve_id

character vector of growth curve identifiers (i.e. if there are multiple measurements done at the same time point, they should have different curve_id)