Create a growth curve data frame that can be later passed to the lag clculation functions
make_grwoth_curve_df(time, biomass, curve_id = NULL)a data frame representing growth curve data
numeric vector of times when biomass was measured (chronologically ordered as in growth curve)
numeric vector of measured biomass values (chronologically ordered as in growth curve)
character vector of growth curve identifiers (i.e. if there are multiple measurements done at the same time point, they should have different curve_id)